@@ -4,6 +4,7 @@ from .request import CryptodotcomRequestMessage
 from .enhanced_websocket import EnhancedWebsocket, EnhancedWebsocketBehaviorSubject
 from .user_balance import UserBalance, PositionBalance
 from .trade import Trade
+from .book import RawOrderbook, RawOrderbookEntry, OrderbookEntryNamedTuple, OrderbookDict
 
 __all__ = [
     "Order",
@@ -18,4 +19,8 @@ __all__ = [
     "UserBalance",
     "PositionBalance",
     "Trade",
+    "RawOrderbook",
+    "RawOrderbookEntry",
+    "OrderbookEntryNamedTuple",
+    "OrderbookDict",
 ]
